import React from "react";
import PropTypes from "prop-types";
import {
  TableCell,
  TableRow,
  IconButton,
  Collapse,
  Tooltip
} from "@material-ui/core";
import { KeyboardArrowDown, KeyboardArrowUp } from "@material-ui/icons";
import { makeStyles } from "@material-ui/core/styles";
import MachineLog from "./MachineLog";
import WakeComponent from "./WakeComponent";

const useRowStyles = makeStyles({
  root: {
    "& > *": {
      borderBottom: "unset"
    }
  }
});

const Machine = ({ machine, actions, logs, addLog }) => {
  const [open, setOpen] = React.useState(false);
  const classes = useRowStyles();

  return (
    <React.Fragment>
      <TableRow className={classes.root}>
        <TableCell>
          <IconButton
            aria-label="expand row"
            size="small"
            onClick={() => setOpen(!open)}
          >
            {open ? <KeyboardArrowUp /> : <KeyboardArrowDown />}
          </IconButton>
        </TableCell>
        <TableCell component="th" scope="row">
          {machine.fullMachineName}
        </TableCell>
        <TableCell>{machine.machineName}</TableCell>
        <TableCell>{machine.iPv4Address}</TableCell>
        <TableCell>{machine.macAddress}</TableCell>
        <TableCell align="right">
          <WakeComponent machine={machine} addLog={addLog} />
          {actions.map(action => (
            <Tooltip
              title={action.tooltip}
              key={`machine-item-${machine.machineId}-${action.code}-tooltip`}
            >
              <span>
                <IconButton
                  id={`machine-item-${machine.machineId}-${action.code}`}
                  size={"small"}
                  onClick={action.effect(machine)}
                >
                  <action.icon />
                </IconButton>
              </span>
            </Tooltip>
          ))}
        </TableCell>
      </TableRow>
      <TableRow>
        <TableCell style={{ paddingBottom: 0, paddingTop: 0 }} colSpan={6}>
          <Collapse in={open} timeout="auto" unmountOnExit>
            <MachineLog logs={logs} />
          </Collapse>
        </TableCell>
      </TableRow>
    </React.Fragment>
  );
};

Machine.propTypes = {
  machine: PropTypes.shape({
    machineId: PropTypes.number.isRequired,
    machineName: PropTypes.string.isRequired,
    fullMachineName: PropTypes.string.isRequired,
    macAddress: PropTypes.string.isRequired,
    iPv4Address: PropTypes.string,
    description: PropTypes.string
  }).isRequired,
  actions: PropTypes.array.isRequired,
  logs: PropTypes.array.isRequired,
  addLog: PropTypes.func.isRequired
};

export default Machine;
