import React, { useContext, useEffect, useCallback } from "react";
import {
  ApplicationStateContext,
  ApplicationDispatchContext
} from "../../../state/ApplicationContexts";
import * as api from "../api";
import MachinesList from "./MachinesList";

const MachinesContainer = () => {
  const state = useContext(ApplicationStateContext);
  const dispatchActions = useContext(ApplicationDispatchContext);

  const handleReadMachines = useCallback(async () => {
    const machines = await api.readMachines();
    const data = Object.assign(machines, { loaded: true });
    dispatchActions.onNetworkChange("machines", data);
  }, [dispatchActions]);

  useEffect(() => {
    if (!state.network.machines.loaded) {
      handleReadMachines();
    }
  }, [handleReadMachines, state.network.machines.loaded]);

  return <MachinesList dense={true} machines={state.network.machines} />;
};

export default MachinesContainer;
